@@ -15,7 +15,11 @@ void KJobWidgets::setWindow(QObject *job, QWidget *widget)
     job->setProperty("widget", QVariant::fromValue(widget));
 
     QWindow *window = widget ? widget->windowHandle() : nullptr;
+    setWindowHandle(job, window);
+}
 
+void KJobWidgets::setWindowHandle(QObject *job, QWindow *window)
+{
     job->setProperty("window", QVariant::fromValue(window));
     if (window) {
         job->setProperty("window-id", QVariant::fromValue(window->winId()));
@@ -27,6 +31,11 @@ QWidget *KJobWidgets::window(QObject *job)
     return job->property("widget").value<QWidget *>();
 }
 
+QWindow *KJobWidgets::windowHandle(QObject *job)
+{
+    return job->property("window").value<QWindow *>();
+}
+
 // duplicated from kwindowsystem
 static int timestampCompare(unsigned long time1_, unsigned long time2_) // like strcmp()
 {
